@@ -9,6 +9,7 @@ from lenstronomy.LensModel.lens_model import LensModel
 from lenstronomy.LensModel.Profiles.curved_arc_spp import CurvedArcSPP
 from lenstronomy.LensModel.Profiles.curved_arc_tan_diff import CurvedArcTanDiff
 from lenstronomy.Util import util
+from lenstronomy.Util import param_util
 
 
 class TestArcDistortions(object):
@@ -175,36 +176,40 @@ class TestArcDistortions(object):
         npt.assert_almost_equal(center_y_spp_arc, 0, decimal=3)
 
     def test_curved_arc_estimate_tan_diff(self):
+        arc_tan_diff = CurvedArcTanDiff()
         lens_model_list = ['SIE']
         lens = LensModel(lens_model_list=lens_model_list)
         arc = LensModel(lens_model_list=['CURVED_ARC_TAN_DIFF'])
         theta_E = 4
-        e1, e2 = 0, -0.1
+
+        # here we model an off-axis ellisoid relative to the x-axis
+        e1, e2 = 0., -0.1
+        x_0, y_0 = 5, 0
         kwargs_lens = [{'theta_E': theta_E, 'e1': e1, 'e2': e2, 'center_x': 0, 'center_y': 0}]
         ext = LensModelExtensions(lensModel=lens)
-        x_0, y_0 = 5, 0.01
-        kwargs_arc = ext.curved_arc_estimate(x_0, y_0, kwargs_lens, tan_diff=True, smoothing_3rd=0.001)
+
+        kwargs_arc = ext.curved_arc_estimate(x_0, y_0, kwargs_lens, tan_diff=True, smoothing_3rd=0.01)
+        theta_E_sie, e1_sie, e2_sie, kappa_ext, center_x_sis, center_y_sis = arc_tan_diff.stretch2sie_mst(**kwargs_arc)
+        print(theta_E_sie, e1_sie, e2_sie, center_x_sis, center_y_sis)
+        npt.assert_almost_equal(e2_sie - e2, 0, decimal=1)
+        npt.assert_almost_equal(e1_sie, e1, decimal=3)
+
+        # here we model an off-axis ellisoid relative to the y-axis
+        e1, e2 = 0.1, 0.
+        x_0, y_0 = 0, 5
+        kwargs_lens = [{'theta_E': theta_E, 'e1': e1, 'e2': e2, 'center_x': 0, 'center_y': 0}]
+        ext = LensModelExtensions(lensModel=lens)
+
+        kwargs_arc = ext.curved_arc_estimate(x_0, y_0, kwargs_lens, tan_diff=True, smoothing_3rd=0.01)
+        theta_E_sie, e1_sie, e2_sie, kappa_ext, center_x_sis, center_y_sis = arc_tan_diff.stretch2sie_mst(**kwargs_arc)
+        print(theta_E_sie, e1_sie, e2_sie, center_x_sis, center_y_sis)
+        npt.assert_almost_equal(e1_sie - e1, 0, decimal=1)
+        npt.assert_almost_equal(e2_sie, e2, decimal=3)
 
         x, y = util.make_grid(numPix=100, deltapix=0.1)
         kappa = lens.kappa(x, y, kwargs_lens)
         kappa_arc = arc.kappa(x, y, [kwargs_arc])
 
-        #import matplotlib.pyplot as plt
-        #plt.matshow(util.array2image(np.log10(kappa_arc)))
-        #plt.show()
-
-        #plt.matshow(util.array2image(np.log10(kappa)))
-        #plt.show()
-
-        arc_tan_diff = CurvedArcTanDiff()
-
-        theta_E_sie, e1_sie, e2_sie, kappa_ext, center_x_sis, center_y_sis = arc_tan_diff.stretch2sie_mst(**kwargs_arc)
-        print(theta_E_sie, e1_sie, e2_sie, center_x_sis, center_y_sis)
-        #TODO this test is relatively imprecise, this may have to do with the inaccuracies of the finite second order differentials
-        npt.assert_almost_equal(e1_sie, e1, decimal=1)
-
-        #npt.assert_almost_equal(kappa_arc, kappa, decimal=1)
-
     def test_arcs_at_image_position(self):
         # lensing quantities
         kwargs_spp = {'theta_E': 1.26, 'gamma': 2., 'e1': 0.1, 'e2': -0.1, 'center_x': 0.0, 'center_y': 0.0}  # parameters of the deflector lens model
@@ -242,6 +247,153 @@ class TestArcDistortions(object):
             npt.assert_almost_equal(center_x_spp_arc, 0, decimal=3)
             npt.assert_almost_equal(center_y_spp_arc, 0, decimal=3)
 
+    def test_analytic_differentials_spp(self):
+        """
+        test the analytical differentials of the spherical power-law mass profile
+
+        :return:
+        """
+        lens_model_class = LensModel(lens_model_list=['SPP'])
+        theta_E = 2
+        gamma = 2.2
+        kwargs_lens = [{'theta_E': theta_E, 'gamma': gamma, 'center_x': 0, 'center_y': 0}]
+        ext = LensModelExtensions(lensModel=lens_model_class)
+        # we leave out the very high magnification region where the numerical differentials might not be as accurate as required in the tests
+        x = np.append(np.linspace(start=0.1, stop=theta_E-0.1, num=9), np.linspace(start=theta_E + 0.1, stop=3 * theta_E, num=9))
+        y = np.zeros_like(x)
+        lambda_rad, lambda_tan, orientation_angle, dlambda_tan_dtan, dlambda_tan_drad, dlambda_rad_drad, dlambda_rad_dtan, dphi_tan_dtan, dphi_tan_drad, dphi_rad_drad, dphi_rad_dtan = ext.radial_tangential_differentials(x, y, kwargs_lens)
+
+        def _lambda_t_analytic(r, theta_E, gamma):
+            """
+            analytic expression for lambda_tan
+
+            :param r: radius
+            :return:
+            """
+            return (1 - (theta_E / r) ** (gamma -1)) ** -1
+
+        lambda_tan_analytic = _lambda_t_analytic(x, theta_E, gamma)
+        npt.assert_almost_equal(lambda_tan_analytic, lambda_tan, decimal=5)
+
+        def _lambda_r_analytic(r, theta_E, gamma):
+            """
+            analytic expression for lambda_rad
+
+            :param r: radius
+            :return:
+            """
+            return (1 + (gamma - 2) * (theta_E/r) ** (gamma - 1)) ** -1
+
+        lambda_rad_analytic = _lambda_r_analytic(x, theta_E, gamma)
+        npt.assert_almost_equal(lambda_rad_analytic, lambda_rad, decimal=5)
+
+        def _lambda_t_dr_analytic(r, theta_E, gamma):
+            """
+            analytic expression for  d(lambda_tan) / dr
+
+            :param r: radius
+            :return:
+            """
+            return (1 - gamma) * (theta_E / r) ** gamma / (theta_E * (1 - (theta_E/r)**(gamma - 1))**2)
+
+        dlambda_tan_drad_analytic = _lambda_t_dr_analytic(x, theta_E, gamma)
+        npt.assert_almost_equal(dlambda_tan_drad_analytic / dlambda_tan_drad, 1, decimal=2)
+
+        def _lambda_r_dr_analytic(r, theta_E, gamma):
+            """
+            analytic expression for  d(lambda_tan) / dr
+
+            :param r: radius
+            :return:
+            """
+            return (1 - gamma) * (2 - gamma) * (theta_E / r) ** gamma / (theta_E * (1 + (theta_E/r)**(gamma - 1) * (gamma - 2))**2)
+
+        dlambda_r_drad_analytic = _lambda_r_dr_analytic(x, theta_E, gamma)
+        npt.assert_almost_equal(dlambda_r_drad_analytic / dlambda_rad_drad, 1, decimal=2)
+
+    def test_analytic_differential_pemd(self):
+        lens_model_class = LensModel(lens_model_list=['EPL'])
+        theta_E = 4
+        gamma = 2.
+
+        ext = LensModelExtensions(lensModel=lens_model_class)
+        # we leave out the very high magnification region where the numerical differentials might not be as accurate as required in the tests
+        x = np.append(np.linspace(start=0.2 * theta_E, stop=theta_E * (1-0.2), num=9),
+                      np.linspace(start=theta_E *(1 + 0.5), stop=3 * theta_E, num=9))
+        y = np.zeros_like(x)
+
+        def _dlambda_t_dr_analytic(r, theta_E, gamma):
+            """
+            analytic expression for  d(lambda_tan) / dr
+
+            :param r: circularized radius
+            :return:
+            """
+            return (1 - gamma) * (theta_E / r) ** gamma / (theta_E * (1 - (theta_E/r)**(gamma - 1))**2)
+
+        def _dlambda_t_dt_analytic(x, y, theta_E, gamma, q, phi_G):
+            # polar coordinates with respect to x-axis
+            r, phi = param_util.cart2polar(x, y, center_x=0, center_y=0)
+            epsilon = (1 - q ** 2) / (1 + q ** 2)
+
+            # radial component in respect to rotation of deflector
+            r_ = r * np.sqrt(1 - epsilon * np.cos(2 * (phi - phi_G)))
+            # equivalent  Einstein radius for elliptical mass definition
+            theta_E_prim = np.sqrt(2 * q / (1 + q**2)) * theta_E
+            dlambda_t_dr = _dlambda_t_dr_analytic(r_, theta_E_prim, gamma)
+            dr_de_t = epsilon * np.sin(2 * (phi - phi_G)) / np.sqrt(1 - epsilon * np.cos(2 * (phi - phi_G)))
+            return dlambda_t_dr * dr_de_t, dlambda_t_dr
+
+        # define ellipticity with axis ratio and orientation
+
+        # ellipticity aligned -> leading to zero differential
+        phi_G, q = 0., 0.7
+        e1, e2 = param_util.phi_q2_ellipticity(phi_G, q)
+        kwargs_lens = [{'theta_E': theta_E, 'gamma': gamma, 'e1': e1, 'e2': e2, 'center_x': 0, 'center_y': 0}]
+        lambda_rad, lambda_tan, orientation_angle, dlambda_tan_dtan, dlambda_tan_drad, dlambda_rad_drad, dlambda_rad_dtan, dphi_tan_dtan, dphi_tan_drad, dphi_rad_drad, dphi_rad_dtan = ext.radial_tangential_differentials(x, y, kwargs_lens)
+        dlambda_tan_dtan_analytic, dlambda_t_dr_analtic = _dlambda_t_dt_analytic(x, y, theta_E, gamma, q, phi_G)
+        npt.assert_almost_equal(dlambda_tan_dtan_analytic, 0, decimal=5)
+        npt.assert_almost_equal(dlambda_tan_dtan, 0, decimal=1)
+
+        # ellipticity aligned -> leading to zero differential
+        phi_G, q = np.pi/2, 0.7
+        e1, e2 = param_util.phi_q2_ellipticity(phi_G, q)
+        kwargs_lens = [{'theta_E': theta_E, 'gamma': gamma, 'e1': e1, 'e2': e2, 'center_x': 0, 'center_y': 0}]
+        lambda_rad, lambda_tan, orientation_angle, dlambda_tan_dtan, dlambda_tan_drad, dlambda_rad_drad, dlambda_rad_dtan, dphi_tan_dtan, dphi_tan_drad, dphi_rad_drad, dphi_rad_dtan = ext.radial_tangential_differentials(
+            x, y, kwargs_lens)
+        dlambda_tan_dtan_analytic, dlambda_t_dr_analtic = _dlambda_t_dt_analytic(x, y, theta_E, gamma, q, phi_G)
+        npt.assert_almost_equal(dlambda_tan_dtan_analytic, 0, decimal=5)
+        npt.assert_almost_equal(dlambda_tan_dtan, 0, decimal=1)
+
+        phi_G, q = np.pi / 4, 0.7
+        e1, e2 = param_util.phi_q2_ellipticity(phi_G, q)
+        kwargs_lens = [{'theta_E': theta_E, 'gamma': gamma, 'e1': e1, 'e2': e2, 'center_x': 0, 'center_y': 0}]
+        lambda_rad, lambda_tan, orientation_angle, dlambda_tan_dtan, dlambda_tan_drad, dlambda_rad_drad, dlambda_rad_dtan, dphi_tan_dtan, dphi_tan_drad, dphi_rad_drad, dphi_rad_dtan = ext.radial_tangential_differentials(
+            x, y, kwargs_lens)
+        dlambda_tan_dtan_analytic, dlambda_t_dr_analtic = _dlambda_t_dt_analytic(x, y, theta_E, gamma, q, phi_G)
+        print(dlambda_rad_drad, 'dlambda_rad')
+        npt.assert_almost_equal(dlambda_tan_drad / dlambda_t_dr_analtic, 1, decimal=2)
+        print(dlambda_tan_dtan_analytic / dlambda_tan_dtan, 'test')
+        npt.assert_almost_equal(dlambda_tan_dtan_analytic / dlambda_tan_dtan, 1, decimal=2)
+
+        phi_G, q = np.pi / 8, 0.7
+        e1, e2 = param_util.phi_q2_ellipticity(phi_G, q)
+        kwargs_lens = [{'theta_E': theta_E, 'gamma': gamma, 'e1': e1, 'e2': e2, 'center_x': 0, 'center_y': 0}]
+        lambda_rad, lambda_tan, orientation_angle, dlambda_tan_dtan, dlambda_tan_drad, dlambda_rad_drad, dlambda_rad_dtan, dphi_tan_dtan, dphi_tan_drad, dphi_rad_drad, dphi_rad_dtan = ext.radial_tangential_differentials(
+            x, y, kwargs_lens)
+        dlambda_tan_dtan_analytic, dlambda_t_dr_analtic = _dlambda_t_dt_analytic(x, y, theta_E, gamma, q, phi_G)
+        print(dlambda_tan_dtan_analytic / dlambda_tan_dtan, 'test')
+        npt.assert_almost_equal(dlambda_tan_dtan_analytic / dlambda_tan_dtan, 1, decimal=2)
+
+        phi_G, q = 0.3, 0.7
+        e1, e2 = param_util.phi_q2_ellipticity(phi_G, q)
+        kwargs_lens = [{'theta_E': theta_E, 'gamma': gamma, 'e1': e1, 'e2': e2, 'center_x': 0, 'center_y': 0}]
+        lambda_rad, lambda_tan, orientation_angle, dlambda_tan_dtan, dlambda_tan_drad, dlambda_rad_drad, dlambda_rad_dtan, dphi_tan_dtan, dphi_tan_drad, dphi_rad_drad, dphi_rad_dtan = ext.radial_tangential_differentials(
+            x, y, kwargs_lens)
+        dlambda_tan_dtan_analytic, dlambda_t_dr_analtic = _dlambda_t_dt_analytic(x, y, theta_E, gamma, q, phi_G)
+        print(dlambda_tan_dtan_analytic / dlambda_tan_dtan, 'test')
+        npt.assert_almost_equal(dlambda_tan_dtan_analytic / dlambda_tan_dtan, 1, decimal=2)
+
 
 if __name__ == '__main__':
     pytest.main("-k TestLensModel")
