@@ -155,7 +155,6 @@ def test_grid_with_coords():
     assert ra_at_xy_0 == 0
     assert dec_at_xy_0 == 0
 
-
 def test_array2image():
     array = np.linspace(1, 100, 100)
     image = util.array2image(array)
@@ -333,6 +332,7 @@ def test_make_subgrid():
     x_grid, y_grid = util.make_grid(numPix, deltapix, subgrid_res=1)
     x_sub_grid, y_sub_grid = util.make_subgrid(x_grid, y_grid, subgrid_res=2)
     assert np.sum(x_grid) == 0
+    assert len(x_grid) == 101*101
     assert x_sub_grid[0] == -50.25
     assert y_sub_grid[17] == -50.25
 
@@ -349,10 +349,14 @@ def test_fwhm2sigma():
 def test_points_on_circle():
     radius = 1
     points = 8
-    ra, dec = util.points_on_circle(radius, points)
+    ra, dec = util.points_on_circle(radius, points, connect_ends=True)
     assert ra[0] == 1
     assert dec[0] == 0
 
+    ra_, dec_ = util.points_on_circle(radius, points-1, connect_ends=False)
+    npt.assert_almost_equal(ra[:-1], ra_, decimal=8)
+    npt.assert_almost_equal(dec[:-1], dec_, decimal=8)
+
 
 def test_convert_bool_list():
     bool_list = util.convert_bool_list(n=10, k=None)
@@ -404,6 +408,12 @@ class TestRaise(unittest.TestCase):
         with self.assertRaises(ValueError):
             util.convert_bool_list(n=2, k=[0.1, True])
 
+    def test_raise_make_grid(self):
+        with self.assertRaises(ValueError):
+            util.make_grid(numPix=1.1, deltapix=1)
+        with self.assertRaises(ValueError):
+            util.make_grid(numPix=[1.1, 1], deltapix=1)
+
 
 if __name__ == '__main__':
     pytest.main()
